==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/sdks/java/extensions/sql/src/main/java/org/apache/beam/sdk/extensions/sql/impl/interpreter/operator/BeamSqlWindowStartExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.extensions.sql.impl.interpreter.operator;

import com.google.common.collect.ImmutableMap;
import org.apache.beam.sdk.transforms.windowing.BoundedWindow;
import org.apache.beam.sdk.transforms.windowing.IntervalWindow;
import org.apache.beam.sdk.values.Row;
import org.apache.calcite.sql.type.SqlTypeName;
import org.joda.time.DateTime;

/**
 * {@code BeamSqlExpression} for {@code HOP_START}, {@code TUMBLE_START}, {@code SESSION_START}
 * operation.
 *
 * <p>These operators returns the <em>start</em> timestamp of window.
 */
public class BeamSqlWindowStartExpression extends BeamSqlExpression {

  @Override
  public boolean accept() {
    return true;
  }

  @Override
  public BeamSqlPrimitive<DateTime> evaluate(
      Row inputRow, BoundedWindow window, ImmutableMap<Integer, Object> correlateEnv) {
    if (window instanceof IntervalWindow) {
      return BeamSqlPrimitive.of(
          SqlTypeName.TIMESTAMP, new DateTime(((IntervalWindow) window).start()));
    } else {
      throw new UnsupportedOperationException(
          "Cannot run HOP_START|TUMBLE_START|SESSION_START on GlobalWindow.");
    }
  }
}

==> apache-beam-2.6.0-source-release.zip: beam-release-2.6.0/sdks/java/extensions/sql/src/main/java/org/apache/beam/sdk/extensions/sql/impl/interpreter/operator/BeamSqlWindowStartExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.extensions.sql.impl.interpreter.operator;

import org.apache.beam.sdk.extensions.sql.impl.interpreter.BeamSqlExpressionEnvironment;
import org.apache.beam.sdk.transforms.windowing.BoundedWindow;
import org.apache.beam.sdk.transforms.windowing.IntervalWindow;
import org.apache.beam.sdk.values.Row;
import org.apache.calcite.sql.type.SqlTypeName;
import org.joda.time.DateTime;

/**
 * {@code BeamSqlExpression} for {@code HOP_START}, {@code TUMBLE_START}, {@code SESSION_START}
 * operation.
 *
 * <p>These operators returns the <em>start</em> timestamp of window.
 */
public class BeamSqlWindowStartExpression extends BeamSqlExpression {

  @Override
  public boolean accept() {
    return true;
  }

  @Override
  public BeamSqlPrimitive<DateTime> evaluate(
      Row inputRow, BoundedWindow window, BeamSqlExpressionEnvironment env) {
    if (window instanceof IntervalWindow) {
      return BeamSqlPrimitive.of(
          SqlTypeName.TIMESTAMP, new DateTime(((IntervalWindow) window).start()));
    } else {
      throw new UnsupportedOperationException(
          "Cannot run HOP_START|TUMBLE_START|SESSION_START on GlobalWindow.");
    }
  }
}
